/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.annotation.content;

import org.xwiki.component.annotation.Role;
import org.xwiki.rendering.syntax.Syntax;
import org.xwiki.stability.Unstable;

/**
 * Component responsible for extracting plain text from inside a given {@code String} depending on the syntax associated
 * with it. For example, the plain text could be extracted from inside an HTML content.
 * 
 * @version $Id: b853ef6ba663e5317cce1858057091673bfc8000 $
 * @since 13.10RC1
 */
@Role
@Unstable
public interface TextExtractor
{
    /**
     * Extract text from content considering the associated syntax.
     *
     * @param content the content from where to extract the text
     * @param syntax content specific syntax
     * @return the plain text
     */
    String extractText(String content, Syntax syntax);
}
