/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test.ui.po;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;

/**
 * Represents the page that displays the status of a copy operation. This page is normally loaded after the user clicks
 * on the Copy button (i.e. after the copy parameters have been submitted).
 * 
 * @version $Id: 78f95e6aca8ae3d8eb4857421791f2fe343c5859 $
 * @since 7.4.1
 * @since 8.0M1
 */
public class CopyOrRenameOrDeleteStatusPage extends BasePage
{
    private static final String MESSAGE_CSS_SELECTOR =
        ".xcontent.job-status .box.successmessage, .xcontent.job-status .box.errormessage";

    @FindBy(css = ".job-status .col-lg-6:first-child .breadcrumb > li:last-child a")
    private WebElement oldPage;

    @FindBy(css = ".job-status .col-lg-6:last-child .breadcrumb > li:last-child a")
    private WebElement newPage;

    @FindBy(css = MESSAGE_CSS_SELECTOR)
    private WebElement message;

    /**
     * Wait until the copy operation finishes.
     * 
     * @return this page
     */
    public CopyOrRenameOrDeleteStatusPage waitUntilFinished()
    {
        // Waits for a success or error message to be displayed before continuing. Previously, this method was waiting 
        // for the job progress bar to be "missing" before continuing, which could happen too early, before the bar was
        // even displayed once.
        getDriver().waitUntilElementIsVisible(By.cssSelector(MESSAGE_CSS_SELECTOR));
        return this;
    }

    public ViewPage gotoOriginalPage()
    {
        this.oldPage.click();
        return new ViewPage();
    }

    public ViewPage gotoNewPage()
    {
        this.newPage.click();
        return new ViewPage();
    }

    public String getInfoMessage()
    {
        return this.message.getText();
    }
}
